<?php
namespace Atarapay\Escrow\Block\Onepage;
class AtarapayEscrow extends \Magento\Framework\View\Element\Template {
    /**
     * @var \Magento\Checkout\Model\Session
     */
    protected $_checkoutSession;
    /**
     * @var \Magento\Sales\Api\OrderRepositoryInterface
     */
    protected $orderRepository;
    protected $helper;
    protected $encryptor;
    protected $page;
    protected $currency;
    protected $store_manager;
    protected $_objectManager;
    /**
     * @param \Magento\Framework\View\Element\Template\Context $context
     * @param \Magento\Checkout\Model\Session $checkoutSession
     * @param \Magento\Sales\Api\OrderRepositoryInterface $orderRepository
     * @param \Atarapay\Escrow\Helper\Data $helper
     * @param array $data
     */
    public function __construct(
        \Magento\Framework\View\Element\Template\Context $context,
        \Magento\Checkout\Model\Session $checkoutSession,
        \Magento\Sales\Api\OrderRepositoryInterface $orderRepository,
        \Atarapay\Escrow\Helper\Data $helper,
        \Magento\Framework\Encryption\EncryptorInterface $encryptor,
        \Magento\Framework\View\Page\Config $page,
        \Magento\Directory\Model\Currency $currency,
        \Magento\Framework\ObjectManagerInterface $objectmanager,
        array $data = []
    ) {
        $this->_checkoutSession = $checkoutSession;
        $this->orderRepository = $orderRepository;
        $this->helper=$helper;
        $this->encryptor = $encryptor;
        $this->page=$page;
        $this->currency=$currency;
        $this->store_manager=$context->getStoreManager();
        $this->_objectManager = $objectmanager;
        if($this->isTestMode()):
                $page->addPageAsset('Atarapay_Escrow::js\test_trustpay.js');
            else:
                $page->addPageAsset('Atarapay_Escrow::js\trustpay.js');
        endif;
        parent::__construct($context, $data);
    }
    public function getRealOrderId(){
        $lastorderId = $this->_checkoutSession->getLastOrderId();
        return $lastorderId;
    }
    public function getOrder($id){
        if($id):
            try{
                return $this->orderRepository->get($id);
            }catch (\Magento\Framework\Exception\NoSuchEntityException $e){
                $this->helper->log($e->getMessage());
            }
        endif;
        return false;
    }
    public function isAtarapayEscrow() {
        $order = $this->getOrder($this->getRealOrderId());
        if($order):
            $payment = $order->getPayment();
            $method = $payment->getMethodInstance();
            if($payment->getMethod()=='atarapay_escrow'):
                return true;
            endif;
        endif;
        return false;
    }
    public function getOrderId(){
        $order = $this->getOrder($this->getRealOrderId());
        if($order):
            return $order->getId();
        endif;
    }
    public function getPaymentParam(){
        $item_name=array();
        $item_desc=array();
        $order = $this->getOrder($this->getRealOrderId());
        if($order):
            foreach($order->getAllVisibleItems() as $item){
                $product = $item->getProduct();
                $item_name[] = $product->getName();
                $item_desc[] = $product->getName();
            }
            $item_name = implode(", ", $item_name);
            $item_desc = implode(", ", $item_desc);
            $sellerphoneno='null';
            if(!empty($this->helper->getStoreConfig('payment/atarapay_escrow/sellerphoneno'))){
                $sellerphoneno=$this->helper->getStoreConfig('payment/atarapay_escrow/sellerphoneno');
            }
            $address = implode(", ", $order->getBillingAddress()->getStreet())." ".$order->getBillingAddress()->getCity()." ".$order->getBillingAddress()->getRegion()." ".$order->getBillingAddress()->getCountryId()." ".$order->getBillingAddress()->getPostcode();
            $atara_params=array();
            if($this->isTestMode()) {
                $atara_params['public_key'] = $this->encryptor->decrypt($this->helper->getStoreConfig('payment/atarapay_escrow/test_merchant_gateway_key'));
            }else{
                $atara_params['public_key'] = $this->encryptor->decrypt($this->helper->getStoreConfig('payment/atarapay_escrow/merchant_gateway_key'));
            }
            $amount_array=$this->calculateAmount($order);
            $atara_params['amount'] = $amount_array['amount'];
            $atara_params['amount_fx']=$amount_array['amount_fx'];
            $atara_params['orderId']=$order->getEntityId();
            $atara_params['currency']=$amount_array['currency_code'];
            $atara_params['customer_email']      = $order->getCustomerEmail();
            $atara_params['customer_phone']      = $order->getBillingAddress()->getTelephone();
            $atara_params['customer_first_name'] = $order->getCustomerFirstname();
            $atara_params['customer_last_name']  = $order->getCustomerLastname();
            $atara_params['address']             = $address;
            $atara_params['country']             = $order->getBillingAddress()->getCountryId();
            $atara_params['items']               = $item_name;
            $atara_params['items_desc']          = $item_desc;
            $atara_params['date']                = $order->getCreatedAt();
            $atara_params['sellerphoneno']       = $this->getSellerPhoneNumber();
            $atara_params['multi_seller']        = $this->isMultiSeller();

            if($this->isDebug()){
                $this->helper->log($atara_params);
            }
            return $atara_params;
        endif;
    }
    public function getSellerPhoneNumber(){
        $sellerphoneno='null';
        if(!empty($this->helper->getStoreConfig('payment/atarapay_escrow/sellerphoneno'))){
            $sellerphoneno=$this->helper->getStoreConfig('payment/atarapay_escrow/sellerphoneno');
        }
        if($this->isMultiSeller() && $this->helper->isMarketPlaceModuleInstalled()){
            $helper = $this->_objectManager->get('\Webkul\Marketplace\Helper\Data');
            $sellerId = [];
            $order = $this->getOrder($this->getRealOrderId());
            foreach($order->getAllItems() as $item) {
                $marketplaceProduct = $helper->getSellerProductDataByProductId($item->getProductId());
                foreach ($marketplaceProduct as $value) {
                    if (!in_array($value['seller_id'], $sellerId)){
                        $sellerId[] = $value['seller_id'];
                    }
                }
            }
            if(count($sellerId) == 1){
                $sellerCollection = $helper->getSellerCollectionObj($sellerId[0]);
                $data = $sellerCollection->getData();
                if(!empty($data)){
                    $sellerphoneno = $data[0]['contact_number'];
                }

            }
        }
        return preg_replace('/\s+/', '', $sellerphoneno);
    }
    public function isTestMode(){
        return $this->helper->getStoreConfig('payment/atarapay_escrow/test');
    }
    public function isDebug(){
        return $this->helper->getStoreConfig('payment/atarapay_escrow/test');
    }
    public function convert_currency($local,$currency,$amount){
        $request = 'https://api.atarapay.com/api/abokiExchangeRate';
        $body = $this->sendRequest($request);
        $data = json_decode( $body );
        if(!empty($data)){
            $rate = $data->data->USDNGN;
			$amountFx = $rate*$amount;
			return $amountFx;
        }
        return $amount;
    }
    public function isMultiSeller(){
        return $this->helper->getStoreConfig('payment/atarapay_escrow/multi_seller');
    }
    public function sendRequest($endpoint, $payload='', $type = 'GET'){
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_FAILONERROR, true);
        if ($type == 'PUT') {
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "PUT");
        }
        if (!empty($payload)) {
            curl_setopt($ch, CURLOPT_POSTFIELDS, $payload);
            curl_setopt($ch, CURLOPT_POST, 1);
        }
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_FRESH_CONNECT, 1);
        curl_setopt($ch, CURLOPT_URL, $endpoint);
        $result = curl_exec($ch);
        if ($result === false) {
            $this->helper->log(curl_error($ch));
            curl_close($ch);
            return false;
        } else {
            curl_close($ch);
            return $result;
        }
    }
    public function calculateAmount($order){
        $currencyCode = $order->getOrderCurrencyCode();
        $baseCurrencyCode = $order->getBaseCurrencyCode();
        $baseGrandTotal = $order->getBaseGrandTotal();
        $atara_params=array();
        if ($order->getOrderCurrencyCode()=='NGN') {
            $atara_params['amount'] = $order->getGrandTotal() * 100;
            $atara_params['amount_fx'] = number_format((float)$order->getGrandTotal(), 2, '.', '');
            $atara_params['currency_code'] = $order->getOrderCurrencyCode();
        }else if($order->getOrderCurrencyCode()=='USD'){
            $currency =  $this->_objectManager->get('\Magento\Store\Model\StoreManagerInterface');
            $currencyRate = $currency->getStore()->getBaseCurrency()->getRate('USD');
            $atara_params['amount'] = $baseGrandTotal * 100;
            $atara_params['amount_fx'] =  $order->getGrandTotal();
            $atara_params['currency_code'] = $order->getOrderCurrencyCode();
        }else{
            $currency = $this->_objectManager->create('Magento\Directory\Model\Currency')->load($baseCurrencyCode);
            $convertedUsdPrice =  $currency->convert($baseGrandTotal,'USD');
            $convertedUsdPrice =  number_format((float)$convertedUsdPrice, 2, '.', '');
            $currency =  $this->_objectManager->get('\Magento\Store\Model\StoreManagerInterface');
            $currencyRate = $currency->getStore()->getBaseCurrency()->getRate('USD');
            //$amount=$this->convert_currency($order->getOrderCurrencyCode(),'USD',$order->getGrandTotal());
            $atara_params['amount'] =$baseGrandTotal*100;
            $atara_params['amount_fx']=number_format((float)$convertedUsdPrice, 2, '.', '');
            $atara_params['currency_code']='USD';
        }
//        var_dump($atara_params);exit;
        return $atara_params;
    }
}