<?php
/**
 * Copyright ©  All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Atarapay\Escrow\Controller\AtaraPay;
use Magento\Sales\Api\OrderRepositoryInterface;
use Magento\Sales\Model\Service\InvoiceService;
use Magento\Framework\DB\Transaction;
use Magento\Sales\Model\Order\Email\Sender\InvoiceSender;
use Psr\Log\LoggerInterface;
use Magento\Sales\Model\Order;
class Invoice extends \Magento\Framework\App\Action\Action{
    protected $resultPageFactory;
    protected $orderRepository;
    protected $invoiceService;
    protected $transaction;
    protected $invoiceSender;
    protected $logger;
    /**
     * Constructor
     * @param \Magento\Framework\App\Action\Context  $context
     * @param \Magento\Framework\View\Result\PageFactory $resultPageFactory
     * @param OrderRepositoryInterface $orderRepository
     * @param InvoiceService $invoiceService
     * @param InvoiceSender $invoiceSender
     * @param Transaction $transaction
     * @param LoggerInterface $logger
     */
    public function __construct(\Magento\Framework\App\Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        OrderRepositoryInterface $orderRepository,
        InvoiceService $invoiceService,
        InvoiceSender $invoiceSender,
        Transaction $transaction,
        LoggerInterface $logger
    ) {
        $this->resultPageFactory = $resultPageFactory;
        $this->orderRepository = $orderRepository;
        $this->invoiceService = $invoiceService;
        $this->transaction = $transaction;
        $this->invoiceSender = $invoiceSender;
        parent::__construct($context);
    }
    /**
     * Execute view action
     *
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute(){
        $resultRedirect = $this->resultRedirectFactory->create();
        try{
            $orderId=$this->getRequest()->getParam('product');
            if(!empty($orderId)):
                $order = $this->orderRepository->get($orderId);
                if ($order->canInvoice()){
                    $invoice = $this->invoiceService->prepareInvoice($order);
                    $invoice->register();
                    $invoice->save();
                    $transactionSave = $this->transaction->addObject($invoice)->addObject($invoice->getOrder());
                    $transactionSave->save();
                    $this->invoiceSender->send($invoice);
                    $order->addStatusHistoryComment(__('Notified customer about invoice creation #%1.', $invoice->getId()))->setIsCustomerNotified(true)->save();
                    $this->messageManager->addSuccessMessage(__('Thank you. Your order has been received.'));
                    $orderState = Order::STATE_PROCESSING;
                    $order->setState($orderState)->setStatus(Order::STATE_PROCESSING);
                    $order->setAtarapayOrderId($this->getRequest()->getParam('order'));
                    $order->save();
                }
            endif;
        }catch (\Exception $ex){
            $this->logger->critical($ex->getMessage());
        }
        return $resultRedirect->setPath('atarapay/atarapay/invoicesuccess',array('order_id'=>$this->getRequest()->getParam('order_id')));
    }
}
