<?php
namespace Atarapay\Escrow\Helper;
use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Store\Model\ScopeInterface;
use Magento\Store\Model\StoreManagerInterface;
class Data extends AbstractHelper{
    protected $storeManager;
    protected $scopeConfig;
    protected $productRepository;
    protected $price_helper;
    protected $encryptor;
    protected $orderRepository;
    protected $moduleManager;
    public function __construct(Context $context,
                                StoreManagerInterface $storeManager,
                                \Magento\Catalog\Model\ProductRepository $productRepository,
                                \Magento\Framework\App\Http\Context $httpContext,
                                \Magento\Framework\Pricing\Helper\Data $price_helper,
                                \Magento\Framework\Encryption\EncryptorInterface $encryptor,
                                \Magento\Sales\Api\OrderRepositoryInterface $orderRepository,
                                \Magento\Framework\Module\Manager $moduleManager
    ) {
        $this->scopeConfig = $context->getScopeConfig();
        $this->storeManager = $storeManager;
        $this->productRepository = $productRepository;
        $this->httpContext = $httpContext;
        $this->price_helper=$price_helper;
        $this->encryptor = $encryptor;
        $this->orderRepository = $orderRepository;
        $this->moduleManager = $moduleManager;
        parent::__construct($context);
    }
    #########################################################################################
    # All Comman function
    #########################################################################################
    public function getStoreConfig($storePath) {
        $storeConfig = $this->scopeConfig->getValue($storePath, ScopeInterface::SCOPE_STORE);
        return $storeConfig;
    }
    public function log($info) {
        $writer = new \Zend\Log\Writer\Stream(BP . '/var/log/atara_pay.log');
        $logger = new \Zend\Log\Logger();
        $logger->addWriter($writer);
        $logger->info($info);
    }
    public function getStoreUrl() {
        return $this->storeManager->getStore()->getBaseUrl();
    }

    public function getProductById($id) {
        return $this->productRepository->getById($id);
    }

    /**
     * Check Customer is login or not
     * @return boolean
     */
    public function isLoggedIn() {
        $isLoggedIn = $this->httpContext->getValue(\Magento\Customer\Model\Context::CONTEXT_AUTH);
        return $isLoggedIn;
    }

    /**
     * Get Formated Price
     * @param fload price
     * @return boolean
     */
    public function getFormatedPrice($price=''){
        return $this->price_helper->currency($price, true, false);
    }
    public function getOrder($id){
        return $this->orderRepository->get($id);
    }
    public function isAtarapayEscrow($id) {
        $order = $this->getOrder($id);
        if($order):
            $payment = $order->getPayment();
            $method = $payment->getMethodInstance();
            if($payment->getMethod()=='atarapay_escrow' && $order->getStatusLabel()=='Pending'):
                return $this->encryptor->encrypt($id);
            endif;
        endif;
        return false;
    }
    public function isMarketPlaceModuleInstalled(){
        if ($this->moduleManager->isOutputEnabled('Webkul_Marketplace')) {
            return true;
        }
        return false;

    }
}